@@ -220,6 +220,21 @@ var sc = ReportStructView.superclass;
                         break;
                 }
             }
+        },
+
+        getMarkableGrid: function() {
+            var activeTab = this.tabControl.getActiveTab();
+
+            if (activeTab.ctrlId === 'eodPanel') {
+                var activeComponent = Ext.Element.getActiveElement(true).component;
+
+                if (!Ext.isEmpty(activeComponent.gridPropertyName))
+                    return this[activeComponent.gridPropertyName];
+                else
+                    return null;
+            }
+
+            return activeTab;
         }
     });
 }(ReportStructView.prototype));
